[Libreoffice-commits] core.git: sw/source
Noel Grandin (via logerrit)
logerrit at kemper.freedesktop.org
Thu Feb 6 06:00:43 UTC 2020
sw/source/core/inc/drawfont.hxx | 2 +-
sw/source/core/inc/txtfrm.hxx | 8 ++++----
sw/source/core/text/frmcrsr.cxx | 2 +-
sw/source/core/text/frmform.cxx | 26 +++++++++++++-------------
sw/source/core/text/frmpaint.cxx | 4 ++--
sw/source/core/text/inftxt.hxx | 2 +-
sw/source/core/text/itradj.cxx | 4 ++--
sw/source/core/text/itrcrsr.cxx | 2 +-
sw/source/core/text/porlay.hxx | 2 +-
sw/source/core/text/txtfrm.cxx | 6 +++---
sw/source/core/txtnode/fntcap.cxx | 2 +-
sw/source/core/txtnode/ndtxt.cxx | 2 +-
12 files changed, 31 insertions(+), 31 deletions(-)
New commits:
commit 1091e4f2140685c4a59a59a43bebc437baf84038
Author: Noel Grandin <noel.grandin at collabora.co.uk>
AuthorDate: Wed Feb 5 15:24:27 2020 +0200
Commit: Noel Grandin <noel.grandin at collabora.co.uk>
CommitDate: Thu Feb 6 07:00:09 2020 +0100
rename SetOfst -> SetOffset
Change-Id: Ic33454dbbbe9c189eb5eebda2c25c6cff3251c84
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/88027
Tested-by: Jenkins
Reviewed-by: Noel Grandin <noel.grandin at collabora.co.uk>
diff --git a/sw/source/core/inc/drawfont.hxx b/sw/source/core/inc/drawfont.hxx
index 44a536454fb1..410943c984d1 100644
--- a/sw/source/core/inc/drawfont.hxx
+++ b/sw/source/core/inc/drawfont.hxx
@@ -463,7 +463,7 @@ public:
m_nLen = nNew;
}
- void SetOfst( sal_Int32 nNew )
+ void SetOffset( sal_Int32 nNew )
{
m_nOfst = nNew;
#ifdef DBG_UTIL
diff --git a/sw/source/core/inc/txtfrm.hxx b/sw/source/core/inc/txtfrm.hxx
index 4076f6a4b814..f76c3b41339f 100644
--- a/sw/source/core/inc/txtfrm.hxx
+++ b/sw/source/core/inc/txtfrm.hxx
@@ -426,8 +426,8 @@ public:
void SplitFrame(TextFrameIndex nTextPos);
SwContentFrame *JoinFrame();
TextFrameIndex GetOffset() const { return mnOffset; }
- void SetOfst_(TextFrameIndex nNewOfst);
- inline void SetOfst (TextFrameIndex nNewOfst);
+ void SetOffset_(TextFrameIndex nNewOfst);
+ inline void SetOffset (TextFrameIndex nNewOfst);
void ManipOfst(TextFrameIndex const nNewOfst) { mnOffset = nNewOfst; }
SwTextFrame *GetFrameAtPos ( const SwPosition &rPos);
inline const SwTextFrame *GetFrameAtPos ( const SwPosition &rPos) const;
@@ -855,10 +855,10 @@ inline const SwTextFrame *SwTextFrame::GetFrameAtPos( const SwPosition &rPos) co
return const_cast<SwTextFrame*>(this)->GetFrameAtPos( rPos );
}
-inline void SwTextFrame::SetOfst(TextFrameIndex const nNewOfst)
+inline void SwTextFrame::SetOffset(TextFrameIndex const nNewOfst)
{
if ( mnOffset != nNewOfst )
- SetOfst_( nNewOfst );
+ SetOffset_( nNewOfst );
}
inline void SwTextFrame::SetRepaint() const
diff --git a/sw/source/core/text/frmcrsr.cxx b/sw/source/core/text/frmcrsr.cxx
index f146433df074..1b14768b5639 100644
--- a/sw/source/core/text/frmcrsr.cxx
+++ b/sw/source/core/text/frmcrsr.cxx
@@ -128,7 +128,7 @@ bool sw_ChangeOffset(SwTextFrame* pFrame, TextFrameIndex nNew)
return false;
nNew = TextFrameIndex(0);
}
- pFrame->SetOfst( nNew );
+ pFrame->SetOffset( nNew );
pFrame->SetPara( nullptr );
pFrame->GetFormatted();
if( pFrame->getFrameArea().HasArea() )
diff --git a/sw/source/core/text/frmpaint.cxx b/sw/source/core/text/frmpaint.cxx
index 9bf759eb6320..ea617b08bf51 100644
--- a/sw/source/core/text/frmpaint.cxx
+++ b/sw/source/core/text/frmpaint.cxx
@@ -431,7 +431,7 @@ SwRect SwTextFrame::GetPaintSwRect()
l = rRepaint.GetRightOfst();
if( l && l > rRepaint.Right() )
rRepaint.Right( l );
- rRepaint.SetOfst( 0 );
+ rRepaint.SetOffset( 0 );
aRet = rRepaint;
// In case our left edge is the same as the body frame's left edge,
@@ -629,7 +629,7 @@ void SwTextFrame::PaintSwFrame(vcl::RenderContext& rRenderContext, SwRect const&
{
const SwFlyFrame *pFly = FindFlyFrame();
if( pFly && pFly->IsFlyInContentFrame() )
- rRepaint.SetOfst( 0 );
+ rRepaint.SetOffset( 0 );
}
// Ge the String for painting. The length is of special interest.
diff --git a/sw/source/core/text/inftxt.hxx b/sw/source/core/text/inftxt.hxx
index b3bf804aff6f..83c173e2db54 100644
--- a/sw/source/core/text/inftxt.hxx
+++ b/sw/source/core/text/inftxt.hxx
@@ -741,7 +741,7 @@ inline SwTwips SwTextPaintInfo::GetPaintOfst() const
inline void SwTextPaintInfo::SetPaintOfst( const SwTwips nNew )
{
- GetParaPortion()->GetRepaint().SetOfst( nNew );
+ GetParaPortion()->GetRepaint().SetOffset( nNew );
}
inline void SwTextPaintInfo::DrawText( const OUString &rText,
diff --git a/sw/source/core/text/itradj.cxx b/sw/source/core/text/itradj.cxx
index b1b712db4274..e3c24e6cf5ca 100644
--- a/sw/source/core/text/itradj.cxx
+++ b/sw/source/core/text/itradj.cxx
@@ -107,7 +107,7 @@ void SwTextAdjuster::FormatBlock( )
GetInfo().SetIdx( m_nStart );
CalcNewBlock( m_pCurr, pFly );
GetInfo().SetIdx( nOldIdx );
- GetInfo().GetParaPortion()->GetRepaint().SetOfst(0);
+ GetInfo().GetParaPortion()->GetRepaint().SetOffset(0);
}
static bool lcl_CheckKashidaPositions( SwScriptInfo& rSI, SwTextSizeInfo& rInf, SwTextIter& rItr,
@@ -666,7 +666,7 @@ void SwTextAdjuster::CalcAdjLine( SwLineLayout *pCurrent )
case SvxAdjust::Center:
{
CalcFlyAdjust( pCurrent );
- pPara->GetRepaint().SetOfst( 0 );
+ pPara->GetRepaint().SetOffset( 0 );
break;
}
case SvxAdjust::Block:
diff --git a/sw/source/core/text/itrcrsr.cxx b/sw/source/core/text/itrcrsr.cxx
index 44d7485185df..f7c116d3ac91 100644
--- a/sw/source/core/text/itrcrsr.cxx
+++ b/sw/source/core/text/itrcrsr.cxx
@@ -1663,7 +1663,7 @@ TextFrameIndex SwTextCursor::GetModelPositionForViewPoint( SwPosition *pPos, con
nX = std::max(0, nX - GetInfo().GetFont()->GetLeftBorderSpace());
}
- aDrawInf.SetOfst( nX );
+ aDrawInf.SetOffset( nX );
if ( nSpaceAdd )
{
diff --git a/sw/source/core/text/porlay.hxx b/sw/source/core/text/porlay.hxx
index 3f7d5575b8a1..ea82202470c1 100644
--- a/sw/source/core/text/porlay.hxx
+++ b/sw/source/core/text/porlay.hxx
@@ -68,7 +68,7 @@ public:
SwRepaint() : SwRect(), nOfst( 0 ), nRightOfst( 0 ) {}
SwTwips GetOffset() const { return nOfst; }
- void SetOfst( const SwTwips nNew ) { nOfst = nNew; }
+ void SetOffset( const SwTwips nNew ) { nOfst = nNew; }
SwTwips GetRightOfst() const { return nRightOfst; }
void SetRightOfst( const SwTwips nNew ) { nRightOfst = nNew; }
};
diff --git a/sw/source/core/text/txtfrm.cxx b/sw/source/core/text/txtfrm.cxx
index 84b5e109320f..874dcc75db99 100644
--- a/sw/source/core/text/txtfrm.cxx
+++ b/sw/source/core/text/txtfrm.cxx
@@ -2665,7 +2665,7 @@ void SwTextFrame::PrepWidows( const sal_uInt16 nNeed, bool bNotify )
if( bSplit )
{
- GetFollow()->SetOfst( aLine.GetEnd() );
+ GetFollow()->SetOffset( aLine.GetEnd() );
aLine.TruncLines( true );
if( pPara->IsFollowField() )
GetFollow()->SetFieldFollow( true );
@@ -2799,7 +2799,7 @@ bool SwTextFrame::Prepare( const PrepareHint ePrep, const void* pVoid,
{
InvalidateRange(SwCharRange(TextFrameIndex(0), TextFrameIndex(1)), 1);
if( GetOffset() && !IsFollow() )
- SetOfst_(TextFrameIndex(0));
+ SetOffset_(TextFrameIndex(0));
}
break;
case PrepareHint::MustFit :
@@ -3071,7 +3071,7 @@ bool SwTextFrame::Prepare( const PrepareHint ePrep, const void* pVoid,
Init();
pPara = nullptr;
if( GetOffset() && !IsFollow() )
- SetOfst_( TextFrameIndex(0) );
+ SetOffset_( TextFrameIndex(0) );
if ( bNotify )
InvalidateSize();
else
diff --git a/sw/source/core/txtnode/fntcap.cxx b/sw/source/core/txtnode/fntcap.cxx
index 98fca76d705f..8ab9cf830b98 100644
--- a/sw/source/core/txtnode/fntcap.cxx
+++ b/sw/source/core/txtnode/fntcap.cxx
@@ -370,7 +370,7 @@ void SwDoCapitalCursorOfst::Do()
rInf.GetText(),
rInf.GetIdx(),
rInf.GetLen(), 0, false );
- aDrawInf.SetOfst( nOfst );
+ aDrawInf.SetOffset( nOfst );
aDrawInf.SetKern( rInf.GetKern() );
aDrawInf.SetKanaComp( rInf.GetKanaComp() );
aDrawInf.SetFrame( rInf.GetFrame() );
diff --git a/sw/source/core/txtnode/ndtxt.cxx b/sw/source/core/txtnode/ndtxt.cxx
index 33c2d67b605a..dccc699ed67b 100644
--- a/sw/source/core/txtnode/ndtxt.cxx
+++ b/sw/source/core/txtnode/ndtxt.cxx
@@ -545,7 +545,7 @@ SwTextNode *SwTextNode::SplitContentNode(const SwPosition & rPos,
pFrame->RegisterToNode( *pNode );
if (!pFrame->IsFollow() && pFrame->GetOffset())
{
- pFrame->SetOfst( TextFrameIndex(0) );
+ pFrame->SetOffset( TextFrameIndex(0) );
}
}
More information about the Libreoffice-commits
mailing list
diff --git a/sw/source/core/text/frmform.cxx b/sw/source/core/text/frmform.cxx
index 47f1345705ca..d8bb575a7c83 100644
--- a/sw/source/core/text/frmform.cxx
+++ b/sw/source/core/text/frmform.cxx
@@ -203,7 +203,7 @@ bool SwTextFrame::CalcFollow(TextFrameIndex const nTextOfst)
bOldInvaContent = pPage->IsInvalidContent();
}
- pMyFollow->SetOfst_( nTextOfst );
+ pMyFollow->SetOffset_( nTextOfst );
pMyFollow->SetFieldFollow( bFollowField );
if( HasFootnote() || pMyFollow->HasFootnote() )
{
@@ -608,7 +608,7 @@ void SwTextFrame::AdjustFollow_( SwTextFormatter &rLine,
if ( nMode )
GetFollow()->ManipOfst(TextFrameIndex(0));
- if ( CalcFollow( nNewOfst ) ) // CalcFollow only at the end, we do a SetOfst there
+ if ( CalcFollow( nNewOfst ) ) // CalcFollow only at the end, we do a SetOffset there
rLine.SetOnceMore( true );
}
}
@@ -751,16 +751,16 @@ void SwTextFrame::SplitFrame(TextFrameIndex const nTextPos)
MoveFlyInCnt( pNew, nTextPos, TextFrameIndex(COMPLETE_STRING) );
// No SetOfst or CalcFollow, because an AdjustFollow follows immediately anyways
pNew->ManipOfst( nTextPos );
}
-void SwTextFrame::SetOfst_(TextFrameIndex const nNewOfst)
+void SwTextFrame::SetOffset_(TextFrameIndex const nNewOfst)
{
// We do not need to invalidate out Follow.
// We are a Follow, get formatted right away and call
- // SetOfst() from there
+ // SetOffset() from there
mnOffset = nNewOfst;
SwParaPortion *pPara = GetPara();
if( pPara )
@@ -1383,7 +1383,7 @@ void SwTextFrame::Format_( SwTextFormatter &rLine, SwTextFormatInfo &rInf,
rReformat.Start() = nNew;
}
- rRepaint.SetOfst( 0 );
+ rRepaint.SetOffset( 0 );
rRepaint.SetRightOfst( 0 );
rRepaint.Chg( getFrameArea().Pos() + getFramePrintArea().Pos(), getFramePrintArea().SSize() );
if( pPara->IsMargin() )
@@ -1620,7 +1620,7 @@ void SwTextFrame::Format_( SwTextFormatter &rLine, SwTextFormatInfo &rInf,
rLine.Bottom();
SwTwips nNewBottom = rLine.Y();
if( nNewBottom < nOldBottom )
- SetOfst_(TextFrameIndex(0));
+ SetOffset_(TextFrameIndex(0));
}
}
}
@@ -1851,13 +1851,13 @@ void SwTextFrame::Format( vcl::RenderContext* pRenderContext, const SwBorderAttr
SwTextSizeInfo aInf( pMaster );
SwTextIter aMasterLine( pMaster, &aInf );
aMasterLine.Bottom();
- SetOfst(aMasterLine.GetEnd());
+ SetOffset(aMasterLine.GetEnd());
}
}
SwTextLineAccess aAccess( this );
const bool bNew = !aAccess.IsAvailable();
- const bool bSetOfst =
+ const bool bSetOffset =
(GetOffset() && GetOffset() > TextFrameIndex(GetText().getLength()));
if( CalcPreps() )
@@ -1874,7 +1874,7 @@ void SwTextFrame::Format( vcl::RenderContext* pRenderContext, const SwBorderAttr
}
SetWidow( false );
}
- else if( bSetOfst && IsFollow() )
+ else if( bSetOffset && IsFollow() )
{
SwTextFrame *pMaster = FindMaster();
OSL_ENSURE( pMaster, "SwTextFrame::Format: homeless follow" );
@@ -1894,9 +1894,9 @@ void SwTextFrame::Format( vcl::RenderContext* pRenderContext, const SwBorderAttr
}
else
{
- // bSetOfst here means that we have the "red arrow situation"
- if ( bSetOfst )
- SetOfst_(TextFrameIndex(0));
+ // bSetOffset here means that we have the "red arrow situation"
+ if ( bSetOffset )
+ SetOffset_(TextFrameIndex(0));
const bool bOrphan = IsWidow();
const SwFootnoteBossFrame* pFootnoteBoss = HasFootnote() ? FindFootnoteBossFrame() : nullptr;
@@ -751,16 +751,16 @@ void SwTextFrame::SplitFrame(TextFrameIndex const nTextPos)
MoveFlyInCnt( pNew, nTextPos, TextFrameIndex(COMPLETE_STRING) );
- // No SetOfst or CalcFollow, because an AdjustFollow follows immediately anyways
+ // No SetOffset or CalcFollow, because an AdjustFollow follows immediately anyways
pNew->ManipOfst( nTextPos );
}